# OrganisationStatus

The organisation's status

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**all_up** | **bool, none_type** | An aggregate status indicating that the organisation is fully ready. | [optional] 
**admin_up** | **bool, none_type** | status of organisation admin portal | [optional] 
**issuer_up** | **bool, none_type** | status of organisation issuer | [optional] 
**current_state** | [**OrganisationStateStatus**](OrganisationStateStatus.md) |  | [optional] 
**capabilities** | [**OrganisationCapabilities**](OrganisationCapabilities.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


